@@ -1,12 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2014-2020 Pytroll developers
+# Copyright (c) 2014-2022 Pytroll developers
 #
-# Author(s):
-#
-#   Adam.Dybbroe <adam.dybbroe@smhi.se>
-#   Panu Lahtinen <panu.lahtinen@fmi.fi>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,21 +19,29 @@
 
 """Reading the spectral responses in the internal pyspectral hdf5 format."""
 
+import logging
 import os
-import numpy as np
 from glob import glob
 from os.path import expanduser
+
+import numpy as np
+
+from pyspectral.bandnames import BANDNAMES
 from pyspectral.config import get_config
-from pyspectral.utils import WAVE_NUMBER
-from pyspectral.utils import WAVE_LENGTH
-from pyspectral.utils import BANDNAMES
-from pyspectral.utils import (INSTRUMENTS, download_rsr)
-from pyspectral.utils import (RSR_DATA_VERSION_FILENAME, RSR_DATA_VERSION)
-from pyspectral.utils import (convert2wavenumber, get_central_wave)
-from pyspectral.utils import convert2str
+from pyspectral.utils import (
+    INSTRUMENTS,
+    RSR_DATA_VERSION,
+    RSR_DATA_VERSION_FILENAME,
+    WAVE_LENGTH,
+    WAVE_NUMBER,
+    check_and_adjust_instrument_name,
+    convert2str,
+    convert2wavenumber,
+    download_rsr,
+    get_bandname_from_wavelength,
+    get_central_wave,
+)
 
-
-import logging
 LOG = logging.getLogger(__name__)
 
 OSCAR_PLATFORM_NAMES = {'eos-2': 'EOS-Aqua',
@@ -48,15 +52,19 @@ OSCAR_PLATFORM_NAMES = {'eos-2': 'EOS-Aqua',
 
 
 class RSRDict(dict):
+    """Helper dict-like class to handle multiple names for band keys."""
+
     def __init__(self, instrument=None):
+        """Initialize dict and primary instrument name."""
         self.instrument = instrument
         dict.__init__(self)
 
     def __getitem__(self, key):
+        """Get value either directly or fallback to pre-configured 'standard' names.."""
         try:
             val = dict.__getitem__(self, key)
         except KeyError:
-            if key in BANDNAMES[self.instrument]:
+            if self.instrument in BANDNAMES and key in BANDNAMES[self.instrument]:
                 val = dict.__getitem__(self, BANDNAMES[self.instrument][key])
             elif key in BANDNAMES['generic']:
                 val = dict.__getitem__(self, BANDNAMES['generic'][key])
@@ -112,43 +120,39 @@ class RSRDataBaseClass(object):
 class RelativeSpectralResponse(RSRDataBaseClass):
     """Container for the relative spectral response functions for various satellite imagers."""
 
-    def __init__(self, platform_name=None, instrument=None, **kwargs):
+    def __init__(self, platform_name=None, instrument=None, filename=None):
         """Initialize the class instance.
 
         Create the instance either from platform name and instrument or from
-        filename and load the data.
+        filename, and then load the data from file.
 
         """
         super(RelativeSpectralResponse, self).__init__()
 
         self.platform_name = platform_name
         self.instrument = instrument
-        self.filename = None
-        self.rsr.instrument = self.instrument
-        if not self.instrument or not self.platform_name:
-            if 'filename' in kwargs:
-                self.filename = kwargs['filename']
-            else:
-                raise AttributeError(
-                    "platform name and sensor or filename must be specified")
-        else:
-            self._check_instrument()
+        self.filename = filename
 
+        self._check_consistent_input()
+
+        self.load()
+        self.rsr.instrument = self.instrument
+
+    def _check_consistent_input(self):
+        """Check consistent input concerning platform name, instrument and RSR file name."""
         if not self.filename:
+            if not self.instrument or not self.platform_name:
+                raise AttributeError(
+                    "Either platform name and sensor, or filename, must be specified")
+
+            self._check_instrument()
             self._get_filename()
 
         self._check_filename_exist()
-        self.load()
 
     def _check_instrument(self):
         """Check and try fix instrument name if needed."""
-        instr = INSTRUMENTS.get(self.platform_name, self.instrument.lower())
-        if instr != self.instrument.lower():
-            self.instrument = instr
-            LOG.warning("Inconsistent instrument/satellite input - " +
-                        "instrument set to %s", self.instrument)
-
-        self.instrument = self.instrument.lower().replace('/', '')
+        self.instrument = check_and_adjust_instrument_name(self.platform_name, self.instrument)
 
     def _get_filename(self):
         """Get the rsr filname from platform and instrument names, and download if not available."""
@@ -178,7 +182,6 @@ class RelativeSpectralResponse(RSRDataBaseClass):
 
     def _check_filename_exist(self):
         """Check that the file exist."""
-
         if not os.path.exists(self.filename) or not os.path.isfile(self.filename):
             errmsg = ('pyspectral RSR file does not exist! Filename = ' +
                       str(self.filename))
@@ -333,27 +336,21 @@ class RelativeSpectralResponse(RSRDataBaseClass):
                 self.set_band_wavelengths_per_detector(h5f, bandname, dname)
                 self.set_band_central_wavelength_per_detector(h5f, bandname, dname)
 
+    def get_bandname_from_wavelength(self, wavelength, epsilon=0.1, multiple_bands=False):
+        """Get the band name from the wavelength."""
+        return get_bandname_from_wavelength(self.instrument, wavelength, self.rsr,
+                                            epsilon=epsilon, multiple_bands=multiple_bands)
 
-def check_and_download(**kwargs):
+
+def check_and_download(dest_dir=None, dry_run=False):
     """Do a check for the version and attempt downloading only if needed."""
-    dry_run = kwargs.get('dry_run', False)
-    dest_dir = kwargs.get('dest_dir', None)
-
     rsr = RSRDataBaseClass()
     if rsr.rsr_data_version_uptodate:
         LOG.info("RSR data already the latest!")
     else:
-        if dest_dir:
-            download_rsr(dest_dir=dest_dir, dry_run=dry_run)
-        else:
-            download_rsr(dry_run=dry_run)
-
-
-def main():
-    """Main."""
-    modis = RelativeSpectralResponse('EOS-Terra', 'modis')
-    del(modis)
+        download_rsr(dest_dir=dest_dir, dry_run=dry_run)
 
 
 if __name__ == "__main__":
-    main()
+    modis = RelativeSpectralResponse('EOS-Terra', 'modis')
+    del modis
