@@ -1,11 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2017, 2018 Pytroll developers
+# Copyright (c) 2017-2022 Pytroll developers
 #
-# Author(s):
-#
-#   Adam.Dybbroe <a000680@c20671.ad.smhi.se>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,15 +17,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Landsat-8 OLI reader
-"""
+"""Landsat-8 OLI reader."""
 
-import os
-from xlrd import open_workbook
-import numpy as np
-from pyspectral.utils import convert2hdf5 as tohdf5
-from pyspectral.raw_reader import InstrumentRSR
 import logging
+import os
+
+import numpy as np
+from xlrd import open_workbook
+
+from pyspectral.raw_reader import InstrumentRSR
+from pyspectral.utils import convert2hdf5 as tohdf5
+
 LOG = logging.getLogger(__name__)
 
 
@@ -44,14 +43,10 @@ OLI_BAND_NAMES = {'CoastalAerosol': 'B1',
 
 
 class OliRSR(InstrumentRSR):
-
-    """Class for Landsat OLI RSR"""
+    """Class for Landsat OLI RSR."""
 
     def __init__(self, bandname, platform_name):
-        """
-        Read the Landsat OLI relative spectral responses for all channels.
-
-        """
+        """Read the Landsat OLI relative spectral responses for all channels."""
         super(OliRSR, self).__init__(bandname, platform_name)
 
         self.instrument = 'oli'
@@ -65,9 +60,7 @@ class OliRSR(InstrumentRSR):
                           str(self.bandname))
 
     def _load(self, scale=0.001):
-        """Load the Landsat OLI relative spectral responses
-        """
-
+        """Load the Landsat OLI relative spectral responses."""
         with open_workbook(self.path) as wb_:
             for sheet in wb_.sheets():
                 if sheet.name in ['Plot of AllBands', ]:
@@ -85,13 +78,8 @@ class OliRSR(InstrumentRSR):
                 break
 
 
-def main():
-    """Main"""
+if __name__ == "__main__":
     bands = OLI_BAND_NAMES.values()
     bands.sort()
     for platform_name in ['Landsat-8', ]:
         tohdf5(OliRSR, platform_name, bands)
-
-
-if __name__ == "__main__":
-    main()
